4.6.4 (2024-03-13)
==================

👷 Bug fixes
------------

- session: using unsafe_cnx_context_manager invoke a recursive auth loop

4.6.3 (2024-02-23)
==================

👷 Bug fixes
------------

- IRQLAdapter: do not fail on a 'None' (or false) result (#1023)
- prevent crash when trying a rql method on a null entity

4.6.2 (2024-02-20)
==================

👷 Bug fixes
------------

- csrf: in storage policy, use base_url as path instead of route_prefix which can be None (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/1017)

4.6.1 (2024-02-07)
==================

🎉 New features
---------------

- auth: add an authentication ticket mechanism to ensure cookies invalidation
- skeleton: add --diff option to black job
- skeleton: add --show-source option to flake8 command

👷 Bug fixes
------------

- migrations: eschema.object_relations are dictionnaries now
- rename RelationSchema._subj_schemas/_obj_schemas to RelationSchema._subject_schemas/_object_schemas
- tests: only datetime with a timezone are accepted now

🤷 Various changes
------------------

- fix: pin sphinx dependencies versions to be able to build with sphinx 4

4.6.0 (2024-01-23)
==================

Important: this release fix a security issue where the CSRF token was always
set on the url path "/" which could be an issue if the cubicweb instance is
installed on a subpath next to others cubicweb instances.

🎉 New features
---------------

- all-in-one: add s3 conf for dbdump
- db-dump: use --output to upload dump to specific path in s3 bucket
- db-restore: add s3 option to restore dump from s3 bucket
- dbdump: add option to push backup to s3
- uilib: uses functools.wraps on our decorators

👷 Bug fixes
------------

- csrf: set csrf_token cookie on the correct url path
- test-instance-creation-with-cubicweb_api: add missing X-Client-Name request headers
- doc: pin sphinx dependencies versions to be able to build with sphinx 4
